(* ::Package:: *)

Off[General::spell]

Model`Name = "SCTM";
Model`NameLaTeX ="Supersymmetric Custodial Triplets Model";
Model`Authors = "Keping Xie";
Model`Date = "2015-07-21";

(* 2015-07-21: changing to new conventions for Superfields, Superpotential and global symmetries *)



(*-------------------------------------------*)
(*   Particle Content*)
(*-------------------------------------------*)

(* Global symmetries *)

Global[[1]] = {Z[2],RParity};
RpM = {-1,-1,1};
RpP = {1,1,-1};

(* Vector Superfields *)

Gauge[[1]]={B,   U[1], hypercharge, g1,False,RpM};
Gauge[[2]]={WB, SU[2], left,        g2,True, RpM};
Gauge[[3]]={G,  SU[3], color,       g3,False,RpM};


(* Chiral Superfields *)
SuperFields[[1]] = {q, 3, {uL,  dL},    1/6, 2, 3, RpM};  
SuperFields[[2]] = {l, 3, {vL,  eL},   -1/2, 2, 1, RpM};
SuperFields[[3]] = {Hd, 1, {Hd0, Hdm},  -1/2, 2, 1, RpP};
SuperFields[[4]] = {Hu, 1, {Hup, Hu0},   1/2, 2, 1, RpP};

SuperFields[[5]] = {d, 3, conj[dR],   1/3, 1, -3, RpM};
SuperFields[[6]] = {u, 3, conj[uR],  -2/3, 1, -3, RpM};
SuperFields[[7]] = {e, 3, conj[eR],     1, 1,  1, RpM};

SuperFields[[8]] =  {Chi, 1, {{Chim/Sqrt[2],Chi0},{Chimm,-Chim/Sqrt[2]}}, -1, 3,  1, RpP};
SuperFields[[9]] =  {Phi, 1, {{Phi0/Sqrt[2],Phip},{Phim,-Phi0/Sqrt[2]}}, 0, 3,  1, RpP};
SuperFields[[10]] = {Psi, 1, {{Psip/Sqrt[2],Psipp},{Psi0,-Psip/Sqrt[2]}}, 1, 3,  1, RpP};

(*------------------------------------------------------*)
(* Superpotential *)
(*------------------------------------------------------*)

SuperPotential =  Yu u.q.Hu - Yd d.q.Hd - Ye e.l.Hd + \[Mu] Hd.Hu+ \[Mu]\[CapitalDelta]/2(Phi.Phi+2 Psi.Chi)+\[Lambda](-Hd.Psi.Hd+Sqrt[2]Hd.Phi.Hu+Hu.Chi.Hu)+\[Lambda]3 Sqrt[2]Chi.Phi.Psi;


(*----------------------------------------------*)
(*   DEFINITION                                 *)
(*----------------------------------------------*)

NameOfStates={GaugeES, EWSB};

(* ----- Before EWSB ----- *)



DEFINITION[GaugeES][DiracSpinors]={
  Bino-> {fB, conj[fB]},
  Wino-> {fWB, conj[fWB]},
  Glu -> {fG, conj[fG]},
  H0  -> {FHd0, conj[FHu0]},
  HC  -> {FHdm, conj[FHup]},
  FTN1 -> {FPhi0,conj[FPhi0]},
  FTN2 -> {FChi0,conj[FPsi0]},
  FTC1 -> {FPhim,conj[FPhip]},
  FTC2 -> {FChim,conj[FPsip]},
  FTCC-> {FChimm,conj[FPsipp]},
  Fd1 -> {FdL, 0},
  Fd2 -> {0, FdR},
  Fu1 -> {FuL, 0},
  Fu2 -> {0, FuR},
  Fe1 -> {FeL, 0},
  Fe2 -> {0, FeR},
  Fv -> {FvL, 0}
};


(* ----- After EWSB ----- *)


(* Gauge Sector *)

DEFINITION[EWSB][GaugeSector] =
{ 
  {{VB,VWB[3]},{VP,VZ},ZZ},
  {{VWB[1],VWB[2]},{VWm,conj[VWm]},ZW},
  {{fWB[1],fWB[2],fWB[3]},{fWm,fWp,fW0},ZfW}
};      
          	

(* ----- VEVs ---- *)

DEFINITION[EWSB][VEVs]= 
  {{SHd0,  {vd, 1/Sqrt[2]},   {Hd0I, I/Sqrt[2]}, {Hd0R,1/Sqrt[2]}},
   {SHu0,  {vu, 1/Sqrt[2]},   {Hu0I, I/Sqrt[2]}, {Hu0R,1/Sqrt[2]}},
   {SChi0, {v3, 1/Sqrt[2]},   {chi0I, I/Sqrt[2]},{chi0R,1/Sqrt[2]}},
   {SPhi0, {v3, 1/Sqrt[2]},   {phi0I, I/Sqrt[2]},{phi0R,1/Sqrt[2]}},
   {SPsi0, {v3, 1/Sqrt[2]},   {psi0I, I/Sqrt[2]},{psi0R,1/Sqrt[2]}}
};


 
(* ---- Mixings ---- *)

DEFINITION[EWSB][MatterSector]= 
{    {{SdL, SdR}, {Sd, ZD}},
     {{SvL}, {Sv, ZV}},
     {{SuL, SuR}, {Su, ZU}},
     {{SeL, SeR}, {Se, ZE}},
     {{Hd0R, Hu0R,chi0R,phi0R,psi0R}, {hh, ZH}},
     {{Hd0I, Hu0I,chi0I,phi0I,psi0I}, {Ah, ZA}},
     {{SHdm,conj[SHup],SChim,SPhim,conj[SPhip],conj[SPsip]},{Hpm,ZP}},
     {{SChimm,conj[SPsipp]},{Hmm,ZMM}},
     {{fB,fW0,FHd0,FHu0,FChi0,FPhi0,FPsi0}, {neu, ZN}}, 
     {{{fWm,FHdm,FChim,FPhim}, {fWp,FHup,FPhip,FPsip}}, {{cham,UM}, {chap,UP}}},
     (*{{{FChimm},{FPsipp}},{{chamm,UMM},{chapp,UPP}}},*)
     {{{FeL},{conj[FeR]}},{{FEL,ZEL},{FER,ZER}}},
     {{{FdL},{conj[FdR]}},{{FDL,ZDL},{FDR,ZDR}}},
     {{{FuL},{conj[FuR]}},{{FUL,ZUL},{FUR,ZUR}}} 
       }; 
       
DEFINITION[EWSB][Phases]= 
{    {fG, PhaseGlu}
    }; 

	
	
DEFINITION[EWSB][DiracSpinors]={
 Fd ->{  FDL, conj[FDR]},
 Fe ->{  FEL, conj[FER]},
 Fu ->{  FUL, conj[FUR]},
 Fv ->{  FvL, 0},
 Neu ->{ neu, conj[neu]},
 Cha ->{ cham, conj[chap]},
 DCha->{FChimm,conj[FPsipp]},
 Glu ->{ fG, conj[fG]}
};	
