(* ::Package:: *)

ParticleDefinitions[GaugeES] = {   
      {SdL,  {  Description -> "Left Down-Squarks"}},
      {SdR,  { Description -> "Right Down-Squarks"}},
      {SuL,  { Description -> "Left Up-Squarks"}}, 
      {SuR,  { Description -> "Right Up-Squarks" }},                
      {SeL,  { Description -> "Left Selectron"}}, 
      {SeR,  { Description -> "Right Selectron"}},                         
      {SvL,  { Description -> "Left Sneutrino"}},     
       {FeL,  { Description -> "Left Electron" }},
       {FeR,  { Description -> "Right Electron" }} ,
       {FvL,  { Description -> "Left Neutrino"}},
       {FdL,  { Description -> "Left Down-Quark" }},
       {FdR,  { Description -> "Right Down-Quark" }},              
       {FuL,  { Description -> "Left Up-Quark" }},
       {FuR,  { Description -> "Right Up-Quark" }},
               
      {SHd0, { Description -> "Neutral Down-Higgs"}},                         
      {SHdm, { Description -> "Charged Down-Higgs"}}, 
      {SHu0, { Description -> "Neutral Up-Higgs"}},                         
      {SHup, { Description -> "Charged Up-Higgs"}},                                                   
      {VB,   { Description -> "B-Boson"}},                                                   
      {VG,   { Description -> "Gluon"}},          
      {VWB,  { Description -> "W-Bosons"}},          
      {gB,   { Description -> "B-Boson Ghost"}},                                                   
      {gG,   { Description -> "Gluon Ghost" }},          
      {gWB,  { Description -> "W-Boson Ghost"}},    
      {Glu,  { Description -> "Gluino"}},
      {Wino, { Description -> "Wino"}},
      {Bino, { Description -> "Bino"}},                                                                                           
      {H0,   { Description -> "Neutral Higgsinos"}},
      {HC,   { Description -> "Charged Higgsinos"}},

      {Fd1,  { Description -> "Dirac Left Down-Quark"}},
      {Fd2,  { Description -> "Dirac Right Down-Quark"}},
      {Fu1,  { Description -> "Dirac Left Up-Quark"}},
      {Fu2,  { Description -> "Dirac Right Up-Quark"}},
      {Fu2,  { Description -> "Dirac Right Up-Quark"}},
      {Fe1,  { Description -> "Dirac Left Electron"}},
      {Fe2,  { Description -> "Dirac Right Electron"}},
      {Fv,   { Description -> "Neutrinos" }},

      {FTN1,   { LaTeX -> "\\tilde{T}_{1}^0",
               FeynArtsNr -> 30,
               OutputName -> TN1 }},
      {FTC1,   { LaTeX -> "\\tilde{T}_{1}^-",
               FeynArtsNr -> 31,
               OutputName -> TC1 }},
      {FTN2,   { LaTeX -> "\\tilde{T}_{2}^0",
               FeynArtsNr -> 32,
               OutputName -> TN2 }},
      {FTC2,   { LaTeX -> "\\tilde{T}_{2}^-",
               FeynArtsNr -> 33,
               OutputName -> TC2 }},
      {FTCC,   { LaTeX -> "\\tilde{T}^{--}",
               FeynArtsNr -> 34,
               OutputName -> TCC }},
      {SPhi0,   { LaTeX -> "\\phi^0",
               FeynArtsNr -> 35,
               OutputName -> Ph0 }},
      {SPhim,   { LaTeX -> "\\phi^-",
               FeynArtsNr -> 37,
               OutputName -> Phm }},
      {SPhip,   { LaTeX -> "\\phi^+",
               FeynArtsNr -> 38,
               OutputName -> Php }},
      {SChi0,   { LaTeX -> "\\chi^0",
               FeynArtsNr -> 39,
               OutputName -> Ch0 }},
      {SChim,   { LaTeX -> "\\chi^-",
               FeynArtsNr -> 40,
               OutputName -> Chm }},
      {SChimm,   { LaTeX -> "\\chi^{--}",
               FeynArtsNr -> 41,
               OutputName -> Cmm }},
      {SPsi0,   { LaTeX -> "\\psi^0",
               FeynArtsNr -> 42,
               OutputName -> Ps0 }},
      {SPsip,   { LaTeX -> "\\psi^+",
               FeynArtsNr -> 43,
               OutputName -> Psp }},
      {SPsipp,   { LaTeX -> "\\psi^{++}",
               FeynArtsNr -> 44,
               OutputName -> Ppp }}
      };
      
      
      
      
  ParticleDefinitions[EWSB] = {  
     {Sd ,  { Description -> "Down-Squarks"}},
     {Su ,  { Description -> "Up-Squarks"}},   
     {Se ,  { Description -> "Sleptons"}}, 
     {Sv ,  { Description -> "Sneutrinos"}}, 
      {Fd,   { Description -> "Down-Quarks"}},   
      {Fu,   { Description -> "Up-Quarks"}},   
      {Fe,   { Description -> "Leptons" }},
      {Fv,   { Description -> "Neutrinos" }},            
            
      {hh ,  { Description -> "Higgs",
                 PDG -> {25,35,45,55,65},
                 PDG.IX -> {101000001,101000002,101000003,101000004,101000005 }}}, 
      {Ah ,  { Description -> "Pseudo-Scalar Higgs",
                 PDG -> {0, 36, 46,56,66},
                 PDG.IX -> {0,102000001,102000002,102000003,102000004 }}},                       
      {Hpm,  { Description -> "Charged Higgs" ,
                 PDG -> {0, -37,-47,-57,-67,-77},
                 PDG.IX ->{0,-100000601,-100000602,-100000603,100000604,-100000605 },
                 LaTeX->{"H^{-}","H^{+}"}
                 }},
      {Hmm,  {   PDG -> {-68, -38},
                 PDG.IX -> {-100001201,-100001202},
                 Width -> {0, External}, 
                 Mass -> {0, LesHouches},
                 FeynArtsNr -> 8,
		         ElectricCharge -> -2,
                 LaTeX -> {"H^{--}","H^{++}"},   
                 OutputName -> {"Hmm","Hpp"}  
                 }},                                                
      {VP,   { Description -> "Photon"}}, 
      {VZ,   { Description -> "Z-Boson"}}, 
      {VG,   { Description -> "Gluon" }},          
      {VWm,  { Description -> "W-Boson" }},        
      {gP,   { Description -> "Photon Ghost"}},                                                   
      {gWm,  { Description -> "Negative W-Boson Ghost"}}, 
      {gWmC, { Description -> "Positive W-Boson Ghost" }}, 
      {gZ,   { Description -> "Z-Boson Ghost" }},
      {gG,   { Description -> "Gluon Ghost" }},                                                                    
      {Glu,  { Description -> "Gluino" }},
      {Neu,  { Description -> "Neutralinos",
                 PDG -> {1000022,1000023,1000025,1000035,1000045, 1000055,1000065},
                 PDG.IX -> {211000001,211000002,211000003,211000004,211000005,211000006,211000007 },
                 LaTeX->"f^0"              
               }},
      {Cha,  { Description -> "Charginos",
               PDG -> {-1000024, -1000037,-1000047,-1000057},
               PDG.IX ->{-210000601,-210000602,-210000603,-210000604},
               LaTeX->{"f^{-}","f^{+}"}
			}},
      {DCha, {   Description->"Double charged fermion",
                 PDG -> {-1000049},
                 PDG.IX ->{-210001201},
                 Mass -> LesHouches,
                 FeynArtsNr -> 16,
		         ElectricCharge -> -2,
                 LaTeX -> {"f^{--}","f^{++}"},
                 OutputName->{"DC"} 
               }}                                                                      
        };    
        
        
        
 WeylFermionAndIndermediate = {
       {FHd0, { Description -> "Neutral Down-Higgsino"}},      
       {FHu0, { Description -> "Neutral Up-Higgsino" }}, 
       {FHdm, { Description -> "Charged Down-Higgsino"}},                                                                                                             
       {FHup, { Description -> "Charged Up-Higgsino"}},
       {neu,   { Description -> "Neutralino Weyl-Spinor"}},
       {cham,   { Description -> "Negative Chargino Weyl-Spinor"}},
       {chap,   { Description -> "Positive Chargino Weyl-Spinor"}}, 
       {chamm,   { Description -> "Double Negative Chargino Weyl-Spinor",LaTeX->"\\tilde{\chi}^{--}",OutputName->chd}},
       {chapp,   { Description -> "Double Positive Chargino Weyl-Spinor",LaTeX->"\\tilde{\psi}^{++}",OutputName->cpp}},
       {fG,   { Description ->"Gluino Weyl-Spinor"}},
       {fWB,  { Description ->"Wino Weyl-Spinor"}},
       {fW0,  { Description ->"Neutral Wino" }},
       {fWm,  { Description ->"Negative Wino"}},                 
       {fWp,  { Description ->"Positive Wino"}},                 
       {fB,   { Description ->"Bino Weyl-Spinor"}},    
       {Hd0R, { Description -> "Scalar Down",LaTeX->"H^{0r}_{d}"}},                                                                       
       {Hu0R, { Description -> "Scalar Up",LaTeX->"H^{0r}_{u}"}}, 
       {Hd0I,   { Description -> "Pseudo Scalar Down",LaTeX->"H^{0i}_{d}"}},                                                                                        
       {Hu0I,   { Description -> "Pseudo Scalar Up",LaTeX->"H^{0i}_{u}" }},
       {SHd,  { Description -> "Down-Higgs"}},
       {SHu,  { Description -> "Up-Higgs"}},
       {FHd,  { Description -> "Down-Higgsino" }},
       {FHu,  { Description -> "Up-Higgsino" }},
       {SChi,  { Description ->"Y=-1 scalar",LaTeX->"X"}},
       {SPhi,  { Description -> "Y=0 scalar",LaTeX->"\\Phi"}},
       {SPsi,  { Description -> "Y=+1 scalar",LaTeX->"\\Psi"}},
       {FChi,  { Description -> "Y=-1 fermion",LaTeX->"\\tilde{X}"}},
       {FPhi,  { Description -> "Y=0 fermion",LaTeX->"\\tilde{\Phi}"}},
       {FPsi,  { Description -> "Y=+1 fermion",LaTeX->"\\tilde{\Psi}"}},                 

       {Hd,   { Description -> "Down-Higgs Superfield"}},                                         
       {Hu,   { Description -> "Up-Higgs Superfield" }},    
       {Chi,   { Description -> "Y=-1 Superfield",LaTeX->"\\hat{X}"}},                                         
       {Phi,   { Description -> "Y=0 Superfield" ,LaTeX->"\\hat{\Phi}"}},   
       {Psi,   { Description -> "Y=+1 Superfield" ,LaTeX->"\\hat{\Psi}"}},
             
       {G,    { Description -> "Gluon Superfield" }},                 
       {B,    { Description -> "B Superfield" }},                 
       {WB,   { Description -> "W Superfield" }},

       {chi0I, { LaTeX -> "\\chi^{0i}" }},
       {chi0R, { LaTeX -> "\\chi^{0r}" }},
       {phi0I, { LaTeX -> "\\phi^{0i}" }},
       {phi0R, { LaTeX -> "\\phi^{0r}" }},
       {psi0I, { LaTeX -> "\\psi^{0i}" }},
       {psi0R, { LaTeX -> "\\psi^{0r}" }},
       {FPhi0,   { LaTeX -> "\\tilde{\phi}^{0}",
               OutputName -> ph4 }},
       {FPhim,   { LaTeX -> "\\tilde{\phi}^{-}",
               OutputName -> ph5 }},
       {FPhip,   { LaTeX -> "\\tilde{\phi}^{+}",
               OutputName -> ph6 }},      
       {FChi0,   { LaTeX -> "\\tilde{\chi}^{0}",
               OutputName -> ch4 }},
       {FChim,   { LaTeX -> "\\tilde{\chi}^{-}",
               OutputName -> ch5 }},
       {FChimm,   { LaTeX -> "\\tilde{\chi}^{--}",
               OutputName -> ch6}},
       {FPsi0,   { LaTeX -> "\\tilde{\psi}^{0}",
               OutputName -> ps4 }},
       {FPsip,   { LaTeX -> "\\tilde{\psi}^{+}",
               OutputName -> ps5 }},
       {FPsipp,   { LaTeX -> "\\tilde{\psi}^{++}",
               OutputName -> ps6 }},
       
       {Sl,   { Description -> "Left Slepton" }},
       {Sq,   { Description -> "Left Squark" }},
       {FeL,  { Description -> "Left Electron" }},
       {FeR,  { Description -> "Right Electron" }} ,
       {FdL,  { Description -> "Left Down-Quark" }},
       {FdR,  { Description -> "Right Down-Quark" }},              
       {FuL,  { Description -> "Left Up-Quark" }},
       {FuR,  { Description -> "Right Up-Quark" }},
       {FEL,  { Description -> "Rotated Left Electron" }},
       {FER,  { Description -> "Rotated Right Electron" }} ,
       {FDL,  { Description -> "Rotated Left Up-Quark" }},
       {FDR,  { Description -> "Rotated Right Up-Quark" }},              
       {FUL,  { Description -> "Rotated Left Down-Quark"}},
       {FUR,  { Description -> "Rotated Right Down-Quark" }}, 
       {Fl,   { Description -> "Left Leptons"}},
       {Fq,   { Description -> "Left Quarks"}}, 
       {FsR,   { Description -> "Weyl Spinor of Singlino"}},
       {FvL,  { Description -> "Left Neutrino"}},

       {e,    { Description -> "Right Electron Superfield" }},
       {d,    { Description -> "Right Down-Quark Superfield" }},                 
       {q,    { Description -> "Left Quark Superfield" }},                 
       {u,    { Description -> "Right Up-Quark Superfield" }},                 
       {l,    { Description -> "left Lepton Superfield" }}

    };                 
